<?php

declare(strict_types = 1);

namespace Drupal\file_extractor\HookHandler;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\file_extractor\Form\SettingsForm;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Hook handler related to requirements.
 */
class RequirementsHandler implements ContainerInjectionInterface {
  use StringTranslationTrait;

  /**
   * The config factory service.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * RequirementsHandler constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory service.
   */
  public function __construct(
    ConfigFactoryInterface $config_factory
  ) {
    $this->configFactory = $config_factory;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) : self {
    return new static(
      $container->get('config.factory')
    );
  }

  /**
   * Implements hook_requirements() for runtime phase.
   */
  public function runtimeRequirements() : array {
    $requirements = [
      'file_extractor' => [
        'title' => $this->t('File Extractor'),
        'value' => $this->t('Cache disabled'),
        'severity' => REQUIREMENT_WARNING,
        'description' => $this->t('Caching of extractions is not enabled. This can cause some performance issues depending on your usage of File Extractor. Notice that this can also cause your database size to increase.'),
      ],
    ];

    $config = $this->configFactory->get(SettingsForm::CONFIG_NAME);
    if ($config->get('cache_enable')) {
      $requirements['file_extractor']['value'] = $this->t('Cache enabled');
      $requirements['file_extractor']['severity'] = REQUIREMENT_INFO;
      $requirements['file_extractor']['description'] = $this->t('Caching of extraction is enabled.');
    }

    return $requirements;
  }

}
